cmd/gomobile: correct init command description

The gomobile init command description currently says that it builds
OpenAL for Android. However, init always initializes the gomobile work
directory and installs gobind, while OpenAL is built only when -openal
is specified.

Update the description to reflect its primary initialization behavior
and make the OpenAL step explicitly optional. Regenerate doc.go.

Change-Id: Ifc240d184970e6fd49bcf2a064e7dd465f7e85f1
Reviewed-on: https://go-review.googlesource.com/c/mobile/+/812540
Reviewed-by: Carlos Amedee <carlos@golang.org>
Reviewed-by: Hajime Hoshi <hajimehoshi@gmail.com>
LUCI-TryBot-Result: golang-scoped@luci-project-accounts.iam.gserviceaccount.com <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Auto-Submit: Carlos Amedee <carlos@golang.org>
Reviewed-by: Dmitri Shuralyov <dmitshur@google.com>
diff --git a/cmd/gomobile/init.go b/cmd/gomobile/init.go
index 86f1401..32f156f 100644
--- a/cmd/gomobile/init.go
+++ b/cmd/gomobile/init.go
@@ -28,7 +28,7 @@
 	run:   runInit,
 	Name:  "init",
 	Usage: "[-openal dir]",
-	Short: "build OpenAL for Android",
+	Short: "initialize gomobile tools and optionally build OpenAL for Android",
 	Long: `
 If a OpenAL source directory is specified with -openal, init will
 build an Android version of OpenAL for use with gomobile build
diff --git a/cmd/gomobile/doc.go b/cmd/gomobile/doc.go
index 1ccd1d1..440bd17 100644
--- a/cmd/gomobile/doc.go
+++ b/cmd/gomobile/doc.go
@@ -24,7 +24,7 @@
 	bind        build a library for Android and iOS
 	build       compile android APK and iOS app
 	clean       remove object files and cached gomobile files
-	init        build OpenAL for Android
+	init        initialize gomobile tools and optionally build OpenAL for Android
 	install     compile android APK and install on device
 	version     print version
 
@@ -140,7 +140,7 @@
 
 # Clean removes object files and cached NDK files downloaded by gomobile init
 
 # Build OpenAL for Android
 
 Usage:
 
@@ -140,7 +140,7 @@
 # Clean removes object files and cached NDK files downloaded by gomobile init
 
-# Build OpenAL for Android
+# Initialize gomobile tools and optionally build OpenAL for Android
 
 Usage: